@@ -19,7 +19,7 @@ package integration
 import (
 	"testing"
 
-	"github.com/GoogleContainerTools/skaffold/integration/skaffold"
+	"github.com/GoogleContainerTools/skaffold/v2/integration/skaffold"
 )
 
 func TestBuildGCBWithExplicitRepo(t *testing.T) {
